==> blesta-5.10.2.zip: blesta/plugins/support_manager/language/tr_tr/admin_tickets.php <==
<?php
/**
 * Admin Tickets
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminTickets.search.no_results'] = 'Arama kriterlerine uyan bilet yok.';
$lang['AdminTickets.search.heading_last_reply_date'] = 'Son Yanıt';
$lang['AdminTickets.search.heading_summary'] = 'Özet';
$lang['AdminTickets.search.heading_department_name'] = 'Departman';
$lang['AdminTickets.search.heading_status'] = 'Durum';
$lang['AdminTickets.search.heading_priority'] = 'Öncelik';
$lang['AdminTickets.search.heading_code'] = 'Bilet Numarası';
$lang['AdminTickets.search.boxtitle_tickets'] = '"%1$s" için Bilet Ara';
$lang['AdminTickets.client.no_results'] = 'Şu anda bu statüde bilet bulunmamaktadır.';
$lang['AdminTickets.client.heading_last_reply_date'] = 'Son Yanıt';
$lang['AdminTickets.client.heading_summary'] = 'Özet';
$lang['AdminTickets.client.heading_department_name'] = 'Departman';
$lang['AdminTickets.client.heading_priority'] = 'Öncelik';
$lang['AdminTickets.client.heading_code'] = 'Bilet Numarası';
$lang['AdminTickets.client.boxtitle_tickets'] = 'Biletler';
$lang['AdminTickets.client.categorylink_createticket'] = 'Açık Bilet';
$lang['AdminTickets.client.category_trash'] = 'Çöp';
$lang['AdminTickets.client.category_closed'] = 'Kapalı';
$lang['AdminTickets.client.category_on_hold'] = 'Beklemede';
$lang['AdminTickets.client.category_in_progress'] = 'Devam Ediyor';
$lang['AdminTickets.client.category_awaiting_reply'] = 'Müşteri Yanıtı Bekleniyor';
$lang['AdminTickets.client.category_open'] = 'Personel Cevabı Bekleniyor';
$lang['AdminTickets.reply.dropzone_remove_file'] = 'Dosyayı Kaldır';
$lang['AdminTickets.reply.dropzone_drop_files_here'] = 'Yüklemek için dosyaları buraya bırakın veya dosyaları seçmek için tıklayın';
$lang['AdminTickets.reply.staff_title'] = 'Destek Personeli';
$lang['AdminTickets.reply.system'] = 'Sistem';
$lang['AdminTickets.reply.log_date'] = '1$s %2$s %3$s tarafından';
$lang['AdminTickets.reply.reply_date'] = '1$s %2$s %3$s tarihinde yanıtlandı';
$lang['AdminTickets.reply.refresh_link'] = 'Görüntülemek için tıklayın.';
$lang['AdminTickets.reply.refresh'] = 'Yeni yanıtlar veya durum değişiklikleri var.';
$lang['AdminTickets.reply.field_actionsubmit'] = 'Git';
$lang['AdminTickets.reply.field_replysubmit'] = 'Bilet Güncelleme';
$lang['AdminTickets.reply.text_add_attachment'] = 'Eklenti Ekle';
$lang['AdminTickets.reply.field_attachments'] = 'Ekler';
$lang['AdminTickets.reply.field_note'] = 'Not';
$lang['AdminTickets.reply.field_reply'] = 'Yanıtla';
$lang['AdminTickets.reply.heading_reply'] = 'Yanıt Ekle';
$lang['AdminTickets.reply.text_with_selected'] = 'Seçilen yanıtlar ile gerçekleştirin:';
$lang['AdminTickets.reply.text_add_response'] = 'Önceden Tanımlanmış Yanıt Ekleme';
$lang['AdminTickets.reply.heading_date_added'] = 'Açıldığı Tarih';
$lang['AdminTickets.reply.heading_status'] = 'Durum';
$lang['AdminTickets.reply.heading_priority'] = 'Öncelik';
$lang['AdminTickets.reply.heading_staff_id'] = 'Atandığı Kişi';
$lang['AdminTickets.reply.heading_department'] = 'Departman';
$lang['AdminTickets.reply.heading_client'] = 'Müşteri';
$lang['AdminTickets.reply.heading_summary'] = 'Özet';
$lang['AdminTickets.reply.boxtitle_reply'] = 'Bilet #%1$s';
$lang['AdminTickets.add.dropzone_remove_file'] = 'Dosyayı Kaldır';
$lang['AdminTickets.add.dropzone_drop_files_here'] = 'Yüklemek için dosyaları buraya bırakın veya dosyaları seçmek için tıklayın';
$lang['AdminTickets.add.text_add_response'] = 'Önceden Tanımlanmış Yanıt Ekleme';
$lang['Admintickets.add.client_placeholder'] = 'Müşteri Kimliği veya Adı';
$lang['AdminTickets.add.field_addsubmit'] = 'Açık Bilet';
$lang['AdminTickets.add.text_add_attachment'] = 'Eklenti Ekle';
$lang['AdminTickets.add.field_details'] = 'Detaylar';
$lang['AdminTickets.add.field_attachments'] = 'Ekler';
$lang['AdminTickets.add.heading_status'] = 'Durum';
$lang['AdminTickets.add.heading_priority'] = 'Öncelik';
$lang['AdminTickets.add.heading_staff_id'] = 'Atandığı Kişi';
$lang['AdminTickets.add.heading_department'] = 'Departman';
$lang['AdminTickets.add.heading_client'] = 'Müşteri';
$lang['AdminTickets.add.heading_summary'] = 'Özet';
$lang['AdminTickets.add.text_no_clients'] = 'Müşteri bulunamadı. Tekrar aramayı deneyin.';
$lang['AdminTickets.add.heading_search_client'] = 'Müşteriyi Arayın';
$lang['AdminTickets.add.boxtitle_add'] = 'Açık Bilet';
$lang['AdminTickets.index.ticket_email'] = '#%1$s %2$s';
$lang['AdminTickets.index.ticket_name'] = '#%1$s %2$s %3$s';
$lang['AdminTickets.index.field_actionsubmit'] = 'Gönder';
$lang['AdminTickets.index.text_no_tickets'] = 'Açık bilet bulunamadı. Tekrar aramayı deneyin.';
$lang['AdminTickets.index.ticket_number_placeholder'] = 'Bilet Numarası';
$lang['AdminTickets.index.text_to_status'] = 'Değiştir:';
$lang['AdminTickets.index.text_to_client'] = 'Müşteriye:';
$lang['AdminTickets.index.text_into_ticket'] = 'Bilete:';
$lang['AdminTickets.index.text_with_selected'] = 'Seçili biletlerle gerçekleştirin:';
$lang['AdminTickets.index.no_results'] = 'Şu anda bu statüde bilet bulunmamaktadır.';
$lang['AdminTickets.index.last_reply_by'] = 'tarafından';
$lang['AdminTickets.index.unassigned'] = 'Atanmamış';
$lang['AdminTickets.index.field_last_reply'] = 'Son Yanıt';
$lang['AdminTickets.index.field_assigned_staff'] = 'Atandığı Kişi';
$lang['AdminTickets.index.field_summary'] = 'Özet';
$lang['AdminTickets.index.field_department_id'] = 'Departman';
$lang['AdminTickets.index.field_priority'] = 'Öncelik';
$lang['AdminTickets.index.field_ticket_number'] = 'Bilet Numarası';
$lang['AdminTickets.index.hours'] = '1$s saat';
$lang['AdminTickets.index.hour'] = '1 saat';
$lang['AdminTickets.index.minutes'] = '1$s dakika';
$lang['AdminTickets.index.any'] = 'Herhangi bir';
$lang['AdminTickets.index.heading_last_reply_date'] = 'Son Yanıt';
$lang['AdminTickets.index.heading_assigned_staff'] = 'Atandığı Kişi';
$lang['AdminTickets.index.heading_summary'] = 'Özet';
$lang['AdminTickets.index.heading_department_name'] = 'Departman';
$lang['AdminTickets.index.heading_priority'] = 'Öncelik';
$lang['AdminTickets.index.heading_client'] = 'Müşteri';
$lang['AdminTickets.index.heading_code'] = 'Bilet Numarası';
$lang['AdminTickets.index.boxtitle_tickets'] = 'Biletler';
$lang['AdminTickets.index.categorylink_createticket'] = 'Açık Bilet';
$lang['AdminTickets.index.category_trash'] = 'Çöp';
$lang['AdminTickets.index.category_closed'] = 'Kapalı';
$lang['AdminTickets.index.category_on_hold'] = 'Beklemede';
$lang['AdminTickets.index.category_in_progress'] = 'Devam Ediyor';
$lang['AdminTickets.index.category_awaiting_reply'] = 'Müşteri Yanıtı Bekleniyor';
$lang['AdminTickets.index.category_open'] = 'Personel Cevabı Bekleniyor';
$lang['AdminTickets.text.unassigned'] = 'Atanmamış';
$lang['AdminTickets.search.page_title'] = '"%1$s" için Arama Sonuçları';
$lang['AdminTickets.reply.page_title'] = 'Destek Yöneticisi > Bilet #%1$s';
$lang['AdminTickets.add.page_title'] = 'Destek Yöneticisi > Bilet Aç';
$lang['AdminTickets.index.page_title'] = 'Destek Yöneticisi > Biletler';
$lang['AdminTickets.!notice.no_departments_staff'] = 'Henüz hiçbir personel ve/veya departman oluşturulmamıştır. Bir departman oluşturmak için yukarıdaki %1$s\'e veya bir personel atamak için %2$s\'e tıklayın.';
$lang['AdminTickets.!success.ticket_delete'] = 'Seçilen biletler başarıyla silindi.';
$lang['AdminTickets.!success.ticket_update_status'] = 'Seçilen biletler başarıyla güncellendi.';
$lang['AdminTickets.!success.ticket_reassign'] = 'Seçilen biletler başarıyla yeniden atandı.';
$lang['AdminTickets.!success.ticket_merge'] = 'Seçilen biletler #%1$s biletiyle başarılı bir şekilde birleştirildi.';
$lang['AdminTickets.!success.ticket_split'] = '1$s numaralı bilet başarılı bir şekilde #%2$s numaralı bilete bölündü.';
$lang['AdminTickets.!success.ticket_updated'] = '1$s numaralı bilet başarıyla güncellendi.';
$lang['AdminTickets.!success.ticket_created'] = '1$s numaralı bilet başarıyla açıldı.';

==> blesta-5.11.4.zip: blesta/plugins/support_manager/language/tr_tr/admin_tickets.php <==
<?php
/**
 * Admin Tickets
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminTickets.search.no_results'] = 'Arama kriterlerine uyan bilet yok.';
$lang['AdminTickets.search.heading_last_reply_date'] = 'Son Yanıt';
$lang['AdminTickets.search.heading_summary'] = 'Özet';
$lang['AdminTickets.search.heading_department_name'] = 'Departman';
$lang['AdminTickets.search.heading_status'] = 'Durum';
$lang['AdminTickets.search.heading_priority'] = 'Öncelik';
$lang['AdminTickets.search.heading_code'] = 'Bilet Numarası';
$lang['AdminTickets.search.boxtitle_tickets'] = '"%1$s" için Bilet Ara';
$lang['AdminTickets.client.no_results'] = 'Şu anda bu statüde bilet bulunmamaktadır.';
$lang['AdminTickets.client.heading_last_reply_date'] = 'Son Yanıt';
$lang['AdminTickets.client.heading_summary'] = 'Özet';
$lang['AdminTickets.client.heading_department_name'] = 'Departman';
$lang['AdminTickets.client.heading_priority'] = 'Öncelik';
$lang['AdminTickets.client.heading_code'] = 'Bilet Numarası';
$lang['AdminTickets.client.boxtitle_tickets'] = 'Biletler';
$lang['AdminTickets.client.categorylink_createticket'] = 'Açık Bilet';
$lang['AdminTickets.client.category_trash'] = 'Çöp';
$lang['AdminTickets.client.category_closed'] = 'Kapalı';
$lang['AdminTickets.client.category_on_hold'] = 'Beklemede';
$lang['AdminTickets.client.category_in_progress'] = 'Devam Ediyor';
$lang['AdminTickets.client.category_awaiting_reply'] = 'Müşteri Yanıtı Bekleniyor';
$lang['AdminTickets.client.category_open'] = 'Personel Cevabı Bekleniyor';
$lang['AdminTickets.reply.dropzone_remove_file'] = 'Dosyayı Kaldır';
$lang['AdminTickets.reply.dropzone_drop_files_here'] = 'Yüklemek için dosyaları buraya bırakın veya dosyaları seçmek için tıklayın';
$lang['AdminTickets.reply.staff_title'] = 'Destek Personeli';
$lang['AdminTickets.reply.system'] = 'Sistem';
$lang['AdminTickets.reply.refresh_link'] = 'Görüntülemek için tıklayın.';
$lang['AdminTickets.reply.refresh'] = 'Yeni yanıtlar veya durum değişiklikleri var.';
$lang['AdminTickets.reply.field_actionsubmit'] = 'Git';
$lang['AdminTickets.reply.field_replysubmit'] = 'Bilet Güncelleme';
$lang['AdminTickets.reply.text_add_attachment'] = 'Eklenti Ekle';
$lang['AdminTickets.reply.field_attachments'] = 'Ekler';
$lang['AdminTickets.reply.field_note'] = 'Not';
$lang['AdminTickets.reply.field_reply'] = 'Yanıtla';
$lang['AdminTickets.reply.heading_reply'] = 'Yanıt Ekle';
$lang['AdminTickets.reply.text_with_selected'] = 'Seçilen yanıtlar ile gerçekleştirin:';
$lang['AdminTickets.reply.text_add_response'] = 'Önceden Tanımlanmış Yanıt Ekleme';
$lang['AdminTickets.reply.heading_date_added'] = 'Açıldığı Tarih';
$lang['AdminTickets.reply.heading_status'] = 'Durum';
$lang['AdminTickets.reply.heading_priority'] = 'Öncelik';
$lang['AdminTickets.reply.heading_staff_id'] = 'Atandığı Kişi';
$lang['AdminTickets.reply.heading_department'] = 'Departman';
$lang['AdminTickets.reply.heading_client'] = 'Müşteri';
$lang['AdminTickets.reply.heading_summary'] = 'Özet';
$lang['AdminTickets.reply.boxtitle_reply'] = 'Bilet #%1$s';
$lang['AdminTickets.add.dropzone_remove_file'] = 'Dosyayı Kaldır';
$lang['AdminTickets.add.dropzone_drop_files_here'] = 'Yüklemek için dosyaları buraya bırakın veya dosyaları seçmek için tıklayın';
$lang['AdminTickets.add.text_add_response'] = 'Önceden Tanımlanmış Yanıt Ekleme';
$lang['Admintickets.add.client_placeholder'] = 'Müşteri Kimliği veya Adı';
$lang['AdminTickets.add.field_addsubmit'] = 'Açık Bilet';
$lang['AdminTickets.add.text_add_attachment'] = 'Eklenti Ekle';
$lang['AdminTickets.add.field_details'] = 'Detaylar';
$lang['AdminTickets.add.field_attachments'] = 'Ekler';
$lang['AdminTickets.add.heading_status'] = 'Durum';
$lang['AdminTickets.add.heading_priority'] = 'Öncelik';
$lang['AdminTickets.add.heading_staff_id'] = 'Atandığı Kişi';
$lang['AdminTickets.add.heading_department'] = 'Departman';
$lang['AdminTickets.add.heading_client'] = 'Müşteri';
$lang['AdminTickets.add.heading_summary'] = 'Özet';
$lang['AdminTickets.add.text_no_clients'] = 'Müşteri bulunamadı. Tekrar aramayı deneyin.';
$lang['AdminTickets.add.heading_search_client'] = 'Müşteriyi Arayın';
$lang['AdminTickets.add.boxtitle_add'] = 'Açık Bilet';
$lang['AdminTickets.index.ticket_email'] = '#%1$s %2$s';
$lang['AdminTickets.index.ticket_name'] = '#%1$s %2$s %3$s';
$lang['AdminTickets.index.field_actionsubmit'] = 'Gönder';
$lang['AdminTickets.index.text_no_tickets'] = 'Açık bilet bulunamadı. Tekrar aramayı deneyin.';
$lang['AdminTickets.index.ticket_number_placeholder'] = 'Bilet Numarası';
$lang['AdminTickets.index.text_to_status'] = 'Değiştir:';
$lang['AdminTickets.index.text_to_client'] = 'Müşteriye:';
$lang['AdminTickets.index.text_into_ticket'] = 'Bilete:';
$lang['AdminTickets.index.text_with_selected'] = 'Seçili biletlerle gerçekleştirin:';
$lang['AdminTickets.index.no_results'] = 'Şu anda bu statüde bilet bulunmamaktadır.';
$lang['AdminTickets.index.last_reply_by'] = 'tarafından';
$lang['AdminTickets.index.unassigned'] = 'Atanmamış';
$lang['AdminTickets.index.field_last_reply'] = 'Son Yanıt';
$lang['AdminTickets.index.field_assigned_staff'] = 'Atandığı Kişi';
$lang['AdminTickets.index.field_summary'] = 'Özet';
$lang['AdminTickets.index.field_department_id'] = 'Departman';
$lang['AdminTickets.index.field_priority'] = 'Öncelik';
$lang['AdminTickets.index.field_ticket_number'] = 'Bilet Numarası';
$lang['AdminTickets.index.hour'] = '1 saat';
$lang['AdminTickets.index.any'] = 'Herhangi bir';
$lang['AdminTickets.index.heading_last_reply_date'] = 'Son Yanıt';
$lang['AdminTickets.index.heading_assigned_staff'] = 'Atandığı Kişi';
$lang['AdminTickets.index.heading_summary'] = 'Özet';
$lang['AdminTickets.index.heading_department_name'] = 'Departman';
$lang['AdminTickets.index.heading_priority'] = 'Öncelik';
$lang['AdminTickets.index.heading_client'] = 'Müşteri';
$lang['AdminTickets.index.heading_code'] = 'Bilet Numarası';
$lang['AdminTickets.index.boxtitle_tickets'] = 'Biletler';
$lang['AdminTickets.index.categorylink_createticket'] = 'Açık Bilet';
$lang['AdminTickets.index.category_trash'] = 'Çöp';
$lang['AdminTickets.index.category_closed'] = 'Kapalı';
$lang['AdminTickets.index.category_on_hold'] = 'Beklemede';
$lang['AdminTickets.index.category_in_progress'] = 'Devam Ediyor';
$lang['AdminTickets.index.category_awaiting_reply'] = 'Müşteri Yanıtı Bekleniyor';
$lang['AdminTickets.index.category_open'] = 'Personel Cevabı Bekleniyor';
$lang['AdminTickets.text.unassigned'] = 'Atanmamış';
$lang['AdminTickets.search.page_title'] = '"%1$s" için Arama Sonuçları';
$lang['AdminTickets.reply.page_title'] = 'Destek Yöneticisi > Bilet #%1$s';
$lang['AdminTickets.add.page_title'] = 'Destek Yöneticisi > Bilet Aç';
$lang['AdminTickets.index.page_title'] = 'Destek Yöneticisi > Biletler';
$lang['AdminTickets.!notice.no_departments_staff'] = 'Henüz hiçbir personel ve/veya departman oluşturulmamıştır. Bir departman oluşturmak için yukarıdaki %1$s\'e veya bir personel atamak için %2$s\'e tıklayın.';
$lang['AdminTickets.!success.ticket_delete'] = 'Seçilen biletler başarıyla silindi.';
$lang['AdminTickets.!success.ticket_update_status'] = 'Seçilen biletler başarıyla güncellendi.';
$lang['AdminTickets.!success.ticket_reassign'] = 'Seçilen biletler başarıyla yeniden atandı.';
$lang['AdminTickets.!success.ticket_merge'] = 'Seçilen biletler #%1$s biletiyle başarılı bir şekilde birleştirildi.';
$lang['AdminTickets.reply.log_date'] = '%1$s tarafından %2$s %3$s';
$lang['AdminTickets.index.hours'] = '%1$s saat';
$lang['AdminTickets.index.minutes'] = '%1$s dakika';
$lang['AdminTickets.!success.ticket_split'] = 'Bilet #%1$s, bilet #%2$s\'ye başarıyla bölündü.';
$lang['AdminTickets.!success.ticket_updated'] = 'Bilet #%1$s başarıyla güncellendi.';
$lang['AdminTickets.!success.ticket_created'] = 'Bilet #%1$s başarıyla açıldı.';
$lang['AdminTickets.reply.reply_date'] = '%1$s adresinde %2$s %3$s yanıtladı';
$lang['AdminTickets.reply.text_contacts'] = 'Seçilmeyen kişiler, yanıt vermeleri halinde otomatik olarak bilete eklenecektir.';
$lang['AdminTickets.reply.text_add_recipient'] = 'Alıcı Ekle';
$lang['AdminTickets.reply.heading_contacts'] = 'İletişim';
$lang['AdminTickets.reply.heading_recipients'] = 'Alıcılar';
$lang['AdminTickets.add.text_contacts'] = 'Seçilmeyen kişiler, yanıt vermeleri halinde otomatik olarak bilete eklenecektir.';
$lang['AdminTickets.add.text_add_recipient'] = 'Alıcı Ekle';
$lang['AdminTickets.add.heading_contacts'] = 'İletişim';
$lang['AdminTickets.add.heading_recipients'] = 'Alıcılar';
